@@ -1,11 +1,15 @@
 
 /* Generated data (by glib-mkenums) */
 
+#ifndef JSON_COMPILATION
+#define JSON_COMPILATION
+#endif
+
 #include "config.h"
 #include "json-enum-types.h"
 
-/* enumerations from "./json-parser.h" */
-#include "./json-parser.h"
+/* enumerations from "../../json-glib/json-parser.h" */
+#include "../../json-glib/json-parser.h"
 
 GType
 json_parser_error_get_type (void)
@@ -35,8 +39,8 @@ json_parser_error_get_type (void)
   return g_enum_type_id__volatile;
 }
 
-/* enumerations from "./json-path.h" */
-#include "./json-path.h"
+/* enumerations from "../../json-glib/json-path.h" */
+#include "../../json-glib/json-path.h"
 
 GType
 json_path_error_get_type (void)
@@ -59,8 +63,8 @@ json_path_error_get_type (void)
   return g_enum_type_id__volatile;
 }
 
-/* enumerations from "./json-reader.h" */
-#include "./json-reader.h"
+/* enumerations from "../../json-glib/json-reader.h" */
+#include "../../json-glib/json-reader.h"
 
 GType
 json_reader_error_get_type (void)
@@ -89,8 +93,8 @@ json_reader_error_get_type (void)
   return g_enum_type_id__volatile;
 }
 
-/* enumerations from "./json-types.h" */
-#include "./json-types.h"
+/* enumerations from "../../json-glib/json-types.h" */
+#include "../../json-glib/json-types.h"
 
 GType
 json_node_type_get_type (void)
